# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetMscSubContactVerificationMessageResult',
    'AwaitableGetMscSubContactVerificationMessageResult',
    'get_msc_sub_contact_verification_message',
    'get_msc_sub_contact_verification_message_output',
]

@pulumi.output_type
class GetMscSubContactVerificationMessageResult:
    """
    A collection of values returned by getMscSubContactVerificationMessage.
    """
    def __init__(__self__, contact_id=None, id=None, status=None, type=None):
        if contact_id and not isinstance(contact_id, str):
            raise TypeError("Expected argument 'contact_id' to be a str")
        pulumi.set(__self__, "contact_id", contact_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, int):
            raise TypeError("Expected argument 'type' to be a int")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="contactId")
    def contact_id(self) -> str:
        return pulumi.get(self, "contact_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The sending status of the message. Valid values : `Success`, `Failed`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> int:
        return pulumi.get(self, "type")


class AwaitableGetMscSubContactVerificationMessageResult(GetMscSubContactVerificationMessageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMscSubContactVerificationMessageResult(
            contact_id=self.contact_id,
            id=self.id,
            status=self.status,
            type=self.type)


def get_msc_sub_contact_verification_message(contact_id: Optional[str] = None,
                                             type: Optional[int] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMscSubContactVerificationMessageResult:
    """
    > **NOTE:** Available in v1.156.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default_msc_sub_contract = alicloud.MscSubContract("defaultMscSubContract",
        contact_name="example_value",
        position="CEO",
        email="123@163.com",
        mobile="153xxxxx906")
    default_msc_sub_contact_verification_message = default_msc_sub_contract.id.apply(lambda id: alicloud.get_msc_sub_contact_verification_message_output(contact_id=id,
        type=1))
    ```


    :param str contact_id: The ID of the Contact.
    :param int type: How a user receives verification messages. Valid values : `1`, `2`.
    """
    __args__ = dict()
    __args__['contactId'] = contact_id
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:index/getMscSubContactVerificationMessage:getMscSubContactVerificationMessage', __args__, opts=opts, typ=GetMscSubContactVerificationMessageResult).value

    return AwaitableGetMscSubContactVerificationMessageResult(
        contact_id=pulumi.get(__ret__, 'contact_id'),
        id=pulumi.get(__ret__, 'id'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'))


@_utilities.lift_output_func(get_msc_sub_contact_verification_message)
def get_msc_sub_contact_verification_message_output(contact_id: Optional[pulumi.Input[str]] = None,
                                                    type: Optional[pulumi.Input[int]] = None,
                                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMscSubContactVerificationMessageResult]:
    """
    > **NOTE:** Available in v1.156.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default_msc_sub_contract = alicloud.MscSubContract("defaultMscSubContract",
        contact_name="example_value",
        position="CEO",
        email="123@163.com",
        mobile="153xxxxx906")
    default_msc_sub_contact_verification_message = default_msc_sub_contract.id.apply(lambda id: alicloud.get_msc_sub_contact_verification_message_output(contact_id=id,
        type=1))
    ```


    :param str contact_id: The ID of the Contact.
    :param int type: How a user receives verification messages. Valid values : `1`, `2`.
    """
    ...
