# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetNetworksNetworkResult',
]

@pulumi.output_type
class GetNetworksNetworkResult(dict):
    def __init__(__self__, *,
                 cidr_block: str,
                 description: str,
                 id: str,
                 is_default: bool,
                 name: str):
        """
        :param str cidr_block: CidrBlock of the CCN instance.
        :param str id: ID of the CCN instance.
        :param bool is_default: IsDefault of the CCN instance.
        :param str name: Name of the CCN instance.
        """
        pulumi.set(__self__, "cidr_block", cidr_block)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_default", is_default)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> str:
        """
        CidrBlock of the CCN instance.
        """
        return pulumi.get(self, "cidr_block")

    @property
    @pulumi.getter
    def description(self) -> str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        ID of the CCN instance.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> bool:
        """
        IsDefault of the CCN instance.
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the CCN instance.
        """
        return pulumi.get(self, "name")


